
# sapiopycommons: Official Sapio Python API Utilities Package

<div align="center"><a href="https://www.sapiosciences.com" target="_blank">
  <img src="https://s3.amazonaws.com/public.exemplareln.com/sapio-pylib/sapio-sciencesofficial-python-api-library.png" alt="Sapio Sciences"><br>
</a></div>

-----------------
[![PyPI Latest Release](https://img.shields.io/pypi/v/sapiopycommons.svg)](https://pypi.org/project/sapiopycommons/) [![License](https://img.shields.io/pypi/l/sapiopycommons.svg)](https://github.com/sapiosciences/sapio-py-tutorials/blob/master/LICENSE)

## What is it?
sapiopycommons is a utilities package, developed and maintained by Sapio Sciences, designed to be used in conjunction with sapiopylib. It provides classes and methods for more easily interacting with the Sapio Informatics Platform's webservice API.

## Where to get it
Installation is simple:
```sh
pip install sapiopycommons
```
However, you may need to pay attention to the library version to ensure it is compatible with your Sapio Informatics Platform.

## Licenses
sapiopycommons is licensed under MPL 2.0.

pypi.org is granted the right to distribute sapiopycommons forever.

This license does not provide any rights to use any other copyrighted artifacts from Sapio Sciences. (And they are typically written in another programming language with no linkages to this library.)

## Dependencies
The following dependencies are required for this package:
- [sapiopylib - The official Sapio Informatics Platform Python API package.](https://pypi.org/project/sapiopylib/)
- [databind - Databind is a library inspired by jackson-databind to de-/serialize Python dataclasses.](https://pypi.org/project/databind/)

## Getting Help
If you have a support contract with Sapio Sciences, please use our [technical support channels](https://sapio-sciences.atlassian.net/servicedesk/customer/portals).

## About Us
Sapio is at the forefront of the Digital Lab with its science-aware platform for managing all your life science data with its integrated Electronic Lab Notebook, LIMS Software and Scientific Data Management System.

Visit us at <a href="https://www.sapiosciences.com">Sapio Sciences</a>.
